@@ -15,6 +15,7 @@ class Extractor(QtCore.QObject):
       QtCore.QObject.__init__(self)
 
       self.url = ''
+      self.userAgent = '' #Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900'
       self.urlPerturb = ''
       self.rideModel = RideModel(id)
       self.parser = None
@@ -71,7 +72,7 @@ class Extractor(QtCore.QObject):
 
       if self.online and self.manager:
          request = QNetworkRequest( QtCore.QUrl(self.url) )
-         request.setRawHeader("User-Agent","Mozilla/5.0");
+         request.setRawHeader("User-Agent", self.userAgent)
          reply = self.manager.get(request)
          self.connect(reply, QtCore.SIGNAL("downloadProgress(qint64, qint64)"), self.updateBar)
 
@@ -92,7 +93,7 @@ class Extractor(QtCore.QObject):
 
       # test d'erreur, en général, pas de connection internet
       if error != QNetworkReply.NoError:
-         DebugLog(html)
+         #DebugLog(html)
          self.rideModel.SetInfo('ERROR', u"Erreur %d, vérifiez votre connection Internet"%error)
 
       #DebugFile(html)
@@ -126,7 +127,7 @@ class Extractor(QtCore.QObject):
             DebugLog("perturbation : %s"%self.urlPerturb)
             self.parsePerturbation =  True
             request = QNetworkRequest( QtCore.QUrl( self.urlPerturb ) )
-            request.setRawHeader("User-Agent","Mozilla/5.0");
+            request.setRawHeader("User-Agent", self.userAgent)
             self.manager.get(request)
 
          if self.parseDetails:
@@ -136,7 +137,7 @@ class Extractor(QtCore.QObject):
                if ride.detailsUrl:
                   #DebugLog("details : %s"%self.urlPerturb)
                   request = QNetworkRequest( QtCore.QUrl(ride.detailsUrl) )
-                  request.setRawHeader("User-Agent","Mozilla/5.0");
+                  request.setRawHeader("User-Agent", self.userAgent)
                   self.manager.get(request)
 
       if self.extracted:
