@@ -1,14 +1,15 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import re, time, os
-from PyQt4 import QtCore, QtGui
+import   os
+from PyQt4 import QtCore
 from PyQt4.QtCore import QAbstractTableModel, Qt, QVariant
 from utils.DebugLog import DebugLog
 from utils.TrainDb import  DbTrain, GareManager
 from utils.Config import TrainTrainConf, ConfFile, RidesConfig
 from extractors.ExtractorTransilien import ExtractorTransilien
 from extractors.ExtractorMetro import ExtractorMetro
+from extractors.ExtractorBus import ExtractorBus
 from extractors.ExtractorRERratp import ExtractorRERratp
 from extractors.ExtractorTramway import ExtractorTramway
 
@@ -64,7 +65,7 @@ class TrainTrainModel(QAbstractTableModel):
 
    def CreateAndAddRide(self, ligne, save=True):
       extractor = None
-      if ligne.tec=='RER' and ligne.exploitant=='S':
+      if (ligne.tec=='Transilien' or ligne.tec=='RER') and ligne.exploitant=='S':
          extractor = ExtractorTransilien(ligne)
 
       elif ligne.tec == 'Metro':
@@ -76,6 +77,9 @@ class TrainTrainModel(QAbstractTableModel):
       elif ligne.tec == 'RER' and ligne.exploitant=='R': # RATP
          extractor = ExtractorRERratp(ligne)
 
+      elif ligne.tec == 'Bus':
+         extractor = ExtractorBus(ligne)
+
       if extractor:
          extractor.rideModel.sens = ligne.sens
          self.rideList[extractor.id] = extractor
