@@ -1,10 +1,23 @@
 ﻿#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-from PyQt4 import QtCore
-import sys, sqlite3, os
+import  sqlite3, os
 from DebugLog import getScriptPath
    
+class DbBus:
+   def __init__(self):
+      datas = os.path.join(os.path.dirname(getScriptPath()), 'datas/bus.sqlite')
+      
+      if not os.path.exists(datas):
+         raise RuntimeError("'%s' not found"%datas)
+
+      conn = sqlite3.connect(datas)
+      self.c = conn.cursor()
+
+   def execute(self, req):
+      self.c.execute(req)
+      return self.c
+      
 class DbTrain:
    def __init__(self):
       datas = os.path.join(os.path.dirname(getScriptPath()), 'datas/tec.sqlite')
