@@ -1,13 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import os, sys, sqlite3, re
+import os, re
 from utils.DebugLog import DebugLog, getScriptPath
 from utils.Config import RidesConfig, ConfFile, RideConf
-from utils.TrainDb import DbTrain
+from utils.TrainDb import DbTrain, DbBus
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QApplication, QCompleter, QLineEdit, QComboBox, QStringListModel
+from PyQt4.QtGui import  QCompleter, QLineEdit, QStringListModel
 
 class Completer(QCompleter):
    def __init__(self, parent=None):
@@ -132,18 +132,104 @@ class AddRideDlg(QtGui.QDialog):
          req = 'AND (%s)'%req
 
       # Get station that are on same line
-      request = 'SELECT name FROM gares,lignes WHERE gares.rowid=lignes.gareid AND name<>"%s" %s GROUP BY name ORDER BY name'%(gareName, req)
-      DebugLog(request)
-      c = self.db.execute(request)
+      req = 'SELECT name FROM gares,lignes WHERE gares.rowid=lignes.gareid AND name<>"%s" %s GROUP BY name ORDER BY name'%(gareName, req)
+      DebugLog(req)
+      c = self.db.execute(req)
       gares=QtCore.QStringList()
       for row in c:
+         DebugLog(row[0])
          gares << row[0]
 
       self.completer2.setStringList(gares)
 
-   def CreateLayouts(self):
-      list = QtCore.QStringList()
 
+   def UpdateCompleterBus(self, line):
+      # With station name, we look for station on same line
+      c = self.dbBus.execute('SELECT name FROM gares WHERE ligne="%s" AND code<>""'%line)
+      gares=QtCore.QStringList()
+      DebugLog("Gares:")
+      for row in c:
+         DebugLog(row[0])
+         gares << row[0]
+      self.completerBD.setStringList(gares)
+
+      DebugLog("Directions:")
+      c = self.dbBus.execute('SELECT name FROM gares WHERE ligne="%s" AND direction<>""'%line)
+      dirs=QtCore.QStringList()
+      for row in c:
+         DebugLog(row[0])
+         dirs << row[0]
+      self.completerBA.setStringList(dirs)
+
+   def CreateLayouts(self):
+      self.tabW = QtGui.QTabWidget()
+
+      self.CreateLayoutMetroRER()
+      self.CreateLayoutBus()
+
+      layout = QtGui.QHBoxLayout()
+      layout.addWidget(self.tabW)
+      self.setLayout(layout)
+
+   def CreateLabelEdit(self, parent, text, completer):
+      label = QtGui.QLabel(parent)
+      label.setText(text)
+      edit = LineEdit(parent)
+      edit.setCompleter(completer)
+      return label, edit
+
+   def PackLabelEdit(self, vbox, label, edit):
+      hbox = QtGui.QHBoxLayout()
+      hbox.addWidget(label)
+      hbox.addWidget(edit)
+      vbox.addLayout(hbox)
+
+   def CreateLayoutBus(self):
+      tab1 = QtGui.QWidget()
+
+      list = QtCore.QStringList()
+      self.dbBus = DbBus()
+      c = self.dbBus.execute('SELECT ligne FROM gares GROUP BY ligne')
+
+      for row in c:
+         list << row[0]
+
+      completer = Completer()
+      completer.setStringList(list)
+      self.completerBD = Completer()
+      self.completerBA = Completer()
+      #self.completerB2.setStringList(list)
+
+      labelBL, self.editBL = self.CreateLabelEdit(tab1, u"Ligne", completer)
+      labelBD, self.editBD = self.CreateLabelEdit(tab1, u"Départ", self.completerBD)
+      labelBA, self.editBA = self.CreateLabelEdit(tab1, u"Direction", self.completerBA)
+
+      self.connect(completer, QtCore.SIGNAL('activated(QString)'), self.editBL.insertCompletion)
+      self.connect(completer, QtCore.SIGNAL('activated(QString)'), self.UpdateCompleterBus)
+
+      c.close()
+
+      vbox = QtGui.QVBoxLayout()
+      self.PackLabelEdit(vbox, labelBL, self.editBL)
+      self.PackLabelEdit(vbox, labelBD, self.editBD)
+      self.PackLabelEdit(vbox, labelBA, self.editBA)
+
+      hLayout3 = QtGui.QHBoxLayout()
+      buttons = QtGui.QDialogButtonBox(tab1)
+      buttons.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
+      self.connect(buttons, QtCore.SIGNAL("accepted()"), self.OnOK)
+      self.connect(buttons, QtCore.SIGNAL("rejected()"), self.OnCancel)
+
+      hLayout3.addWidget(buttons)
+      vbox.addLayout(hLayout3)
+      tab1.setLayout(vbox)
+
+      self.tabW.addTab(tab1, u'Bus')
+
+   def CreateLayoutMetroRER(self):
+      tab1 = QtGui.QWidget()
+
+      list = QtCore.QStringList()
       self.db = DbTrain()
       c = self.db.execute('SELECT * FROM gares ORDER BY name')
 
@@ -156,53 +242,29 @@ class AddRideDlg(QtGui.QDialog):
       self.completer2 = Completer()
       self.completer2.setStringList(list)
 
-      self.editD = LineEdit()
-      self.editD.setCompleter(completer)
+      labelD, self.editD = self.CreateLabelEdit(tab1, u"Départ", completer)
+      labelA, self.editA = self.CreateLabelEdit(tab1, u"Arrivée", self.completer2)
+      vbox = QtGui.QVBoxLayout()
+      vbox.addWidget(labelD)
+      vbox.addWidget(self.editD)
+      vbox.addWidget(labelA)
+      vbox.addWidget(self.editA)
+
       self.connect(completer, QtCore.SIGNAL('activated(QString)'), self.editD.insertCompletion)
       self.connect(completer, QtCore.SIGNAL('activated(QString)'), self.UpdateCompleter2)
 
-      self.editA = LineEdit()
-      self.editA.setCompleter(self.completer2)
-
-      c.close()
-
-      labelD = QtGui.QLabel()
-      labelD.setText(u"Départ")
-      labelA= QtGui.QLabel()
-      labelA.setText(u"Arrivée")
-
-      # lignesList = QtCore.QStringList()
-      # lignesList << 'Tous' << 'RER A' << 'RER B' << 'RER C' << 'RER D' << 'RER E'
-      # ligneD = QtGui.QComboBox()
-      # ligneD.addItems( lignesList )
-      # ligneA = QtGui.QComboBox()
-      # ligneA.addItems( lignesList )
-
-      hLayout1 = QtGui.QHBoxLayout()
-#      hLayout1.addWidget(ligneD)
-      hLayout1.addWidget(self.editD)
-
-      hLayout2 = QtGui.QHBoxLayout()
- #     hLayout2.addWidget(ligneA)
-      hLayout2.addWidget(self.editA)
-
-      vbox = QtGui.QVBoxLayout()
-      vbox.addWidget(labelD)
-
-      vbox.addLayout(hLayout1)
-      vbox.addWidget(labelA)
-      vbox.addLayout(hLayout2)
-
       hLayout3 = QtGui.QHBoxLayout()
-      buttons = QtGui.QDialogButtonBox()
+      buttons = QtGui.QDialogButtonBox(tab1)
       buttons.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
       self.connect(buttons, QtCore.SIGNAL("accepted()"), self.OnOK)
       self.connect(buttons, QtCore.SIGNAL("rejected()"), self.OnCancel)
 
       hLayout3.addWidget(buttons)
       vbox.addLayout(hLayout3)
+      tab1.setLayout(vbox)
 
-      self.setLayout(vbox)
+      self.tabW.addTab(tab1, u'Métro/RER')
+      self.editD.setFocus()
 
    def ReadConfig(self):
       if self.garesConf:
@@ -228,7 +290,9 @@ class AddRideDlg(QtGui.QDialog):
       if not arrivee:
          raise RuntimeError("Gare d'arrivée non renseignée")
 
-      c = self.db.execute('SELECT ligne FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid' % depart)
+      req = 'SELECT ligne FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid' % depart
+      DebugLog(req)
+      c = self.db.execute(req)
       lignesD=[]
       for row in c:
          lignesD.append(row[0])
@@ -237,7 +301,9 @@ class AddRideDlg(QtGui.QDialog):
          DebugLog("Gare '%s' inconnue"%depart)
          raise RuntimeError("Gare '%s' inconnue"%depart)
 
-      c = self.db.execute('SELECT ligne FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid' % arrivee)
+      req = 'SELECT ligne FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid' % arrivee
+      DebugLog(req)
+      c = self.db.execute(req)
 
       lignesA=[]
       for row in c:
@@ -250,6 +316,7 @@ class AddRideDlg(QtGui.QDialog):
       if len(lignesA)==0:
          DebugLog("Gare '%s' inconnue"%arrivee)
          raise RuntimeError("Gare '%s' inconnue"%arrivee)
+
       elif len(lignesA)>1:
          selLigneDlg = SelectLine(lignesA)
          selLigneDlg.exec_()
@@ -286,6 +353,8 @@ class AddRideDlg(QtGui.QDialog):
          tec = 'Metro'
       elif ligne[0]=='R':
          tec = 'RER'
+      elif ligne[0:2]=='TR':
+         tec = 'Transilien'
       elif ligne[0]=='T':
          tec = 'Tramway'
       else:
@@ -320,7 +389,10 @@ class AddRideDlg(QtGui.QDialog):
                   DebugLog('exploitantD==S %s'%res[1])
                   codeArrivee = res[1]
 
-      ligne = ligne[1:]
+      if ligne[0:2]=='TR':
+         ligne=ligne[2:]
+      else:
+         ligne = ligne[1:]
       arrivee = res[0]
       if res[3]:
          posArrivee = int(res[3])
@@ -339,9 +411,44 @@ class AddRideDlg(QtGui.QDialog):
          self.garesConf.AddRide(l)
       return l
 
+   def AddTrajetBus(self, ligne, depart, direction):
+      if not depart:
+         raise RuntimeError(u"Gare de départ non renseignée")
+
+      if not direction:
+         raise RuntimeError(u"Direction non renseignée")
+
+      c = self.dbBus.execute("SELECT code FROM gares WHERE gares.name='%s' AND gares.ligne='%s'"%(depart,ligne))
+      row = c.fetchone()
+
+      if not row:
+         DebugLog("Gare '%s' inconnue"%depart)
+         raise RuntimeError("Gare '%s' inconnue"%depart)
+
+      codeDepart = row[0]
+
+      c = self.dbBus.execute("SELECT direction FROM gares WHERE gares.name='%s' AND gares.ligne='%s' AND direction<>''"%(direction,ligne))
+      row = c.fetchone()
+
+      if not row:
+         DebugLog("Gare '%s' inconnue"%direction)
+         raise RuntimeError("Gare '%s' inconnue"%direction)
+
+      dir = row[0]
+      tec = 'Bus'
+      DebugLog('posD=%s, dir=%s'%(codeDepart, str(direction)))
+
+      l = RideConf(str(ligne), tec, str(depart), '', codeDepart, '', 'R', dir, self.sens)
+      if self.garesConf:
+         self.garesConf.AddRide(l)
+      return l
+
    def OnOK(self):
       try:
-         self.added = self.AddTrajet( self.editD.text(), self.editA.text() )
+         if self.tabW.currentIndex()==0:
+            self.added = self.AddTrajet( self.editD.text(), self.editA.text() )
+         elif self.tabW.currentIndex()==1:
+            self.added = self.AddTrajetBus( self.editBL.text(), self.editBD.text(), self.editBA.text() )
          self.WriteConfig()
       except RuntimeError, e:
          u=unicode(str(e), 'utf-8')
