@@ -56,9 +56,11 @@ class TrainTrainView(QtGui.QMainWindow):
       dlg = SettingsDlg()
       dlg.exec_()
       self.model.ReadConfig()
-      self.timer.setInterval(self.model.ttConf.refreshRateSec()*1000)
+      rate = self.model.ttConf.refreshRate()
+      self.updateauto.setText(u"Rafraîchissement auto %s"%rate)
       for view in self.views.values():
-         view.SetRefreshAutoRate(self.model.ttConf.refreshRate())
+         view.SetRefreshAutoRate(rate)
+      self.timer.setInterval(rate*1000)
 
    def AddRide(self):
       dlg = AddRideDlg(self.model.garesConf, self.tabW.currentIndex())
@@ -73,7 +75,7 @@ class TrainTrainView(QtGui.QMainWindow):
       dlg.exec_()
       ride = dlg.added
       if ride:
-         ride.id='simple'
+         ride.id='simple%d'%self.layoutSimple.count()
          rideModel = self.model.CreateAndAddRide(ride, False)
          self.AddRideView(rideModel, 2)
 
@@ -97,7 +99,7 @@ class TrainTrainView(QtGui.QMainWindow):
 
    def RemoveView(self, view):
       DebugLog("TrainTrainView::RemoveView(%s)"%view.model.id)
-      if view.model.id!='simple':
+      if view.model.id[0:6]!='simple':
          self.model.RemoveRideModel(view.model)
       self.layoutAller.removeWidget(view)
       del self.views[view.model.id]
@@ -122,10 +124,11 @@ class TrainTrainView(QtGui.QMainWindow):
       update.setShortcut('Ctrl+R')
       self.connect(update, QtCore.SIGNAL('triggered()'), self.Refresh)
 
-      updateauto = QtGui.QAction(u'Rafraîchissement auto', self)
-      updateauto.setShortcut('Ctrl+B')
-      updateauto.setCheckable(True)
-      self.connect(updateauto, QtCore.SIGNAL('triggered()'), self.RefreshAuto)
+      rr = self.model.ttConf.refreshRate()
+      self.updateauto = QtGui.QAction(u'Rafraîchissement auto %s'%rr, self)
+      self.updateauto.setShortcut('Ctrl+B')
+      self.updateauto.setCheckable(True)
+      self.connect(self.updateauto, QtCore.SIGNAL('triggered()'), self.RefreshAuto)
 
       settings = QtGui.QAction(u'Paramètres', self)
       settings.setShortcut('Ctrl+O')
@@ -138,7 +141,7 @@ class TrainTrainView(QtGui.QMainWindow):
       file = menubar.addMenu('&Options')
       file.addAction(add)
       file.addAction(update)
-      file.addAction(updateauto)
+      file.addAction(self.updateauto)
       file.addAction(settings)
       file.addAction(about)
 
@@ -148,7 +151,6 @@ class TrainTrainView(QtGui.QMainWindow):
       addButton = QtGui.QPushButton('Ajouter un trajet')
       addButton.clicked.connect(self.AddRide)
       layoutAller.addWidget(addButton)
-#      addButton.setStyleSheet('background-color:#2684DB; color: #fff; margin: 4px')
 
       self.layoutRetour = self.GetLayout(QtGui.QVBoxLayout(), Qt.AlignTop)
       layoutRetour = self.GetLayout(QtGui.QVBoxLayout())
@@ -156,18 +158,17 @@ class TrainTrainView(QtGui.QMainWindow):
       addRetourButton = QtGui.QPushButton('Ajouter un trajet retour')
       addRetourButton.clicked.connect(self.AddRide)
       layoutRetour.addWidget(addRetourButton)
-#      addRetourButton.setStyleSheet('background-color:#2684DB; color: #fff; margin: 4px')
+
+      self.layoutSimple = self.GetLayout(QtGui.QVBoxLayout(), Qt.AlignTop)
+      layoutSimple = self.GetLayout(QtGui.QVBoxLayout())
+      layoutSimple.addLayout(self.layoutSimple)
+      addButtonU = QtGui.QPushButton('Voir un trajet simple')
+      addButtonU.clicked.connect(self.AddRideSimple)
+      layoutSimple.addWidget(addButtonU)
 
       self.allerArea = self.CreateScrollWidget(layoutAller)
       self.retourArea = self.CreateScrollWidget(layoutRetour)
-
-      self.layoutSimple = self.GetLayout(QtGui.QVBoxLayout(), Qt.AlignTop)
-      addButtonU = QtGui.QPushButton('Voir un trajet simple')
-      addButtonU.clicked.connect(self.AddRideSimple)
-      self.layoutSimple.addWidget(addButtonU)
-#      addButtonU.setStyleSheet('background-color:#2684DB; color: #fff; margin: 4px')
-
-      self.scrollAreaU = self.CreateScrollWidget(self.layoutSimple)
+      self.scrollAreaU = self.CreateScrollWidget(layoutSimple)
 
       self.tabW = QtGui.QTabWidget()
       self.tabW.setTabPosition(QtGui.QTabWidget.East)
